import "date-fns";
import React from "react";
import {
  Button,
  Checkbox,
  Fab,
  Grid,
  TextField,
  FormControl,
  FormControlLabel,
  Select,
  MenuItem,
  Paper,
  Typography,
  Divider,
  Switch,
  Table,
  TableCell,
  TableHead,
  TableRow,
  TableBody,
  IconButton,
  Input,
  InputLabel,
  InputAdornment
} from "@material-ui/core";
import Slider from "@material-ui/lab/Slider";
import TrashIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import SearchIcon from "@material-ui/icons/Search";
import SaveAltIcon from "@material-ui/icons/SaveAlt";
import SendIcon from "@material-ui/icons/Send";
import MoreHorizonIcon from "@material-ui/icons/MoreHoriz";
import FilterListIcon from "@material-ui/icons/FilterList";
import MoreHoriz from "@material-ui/icons/MoreHoriz";
import ListAltIcon from "@material-ui/icons/ListAlt";
import { makeStyles } from "@material-ui/core/styles";
import DateFnsUtils from "@date-io/date-fns";
import {
  MuiPickersUtilsProvider,
  KeyboardTimePicker,
  KeyboardDatePicker
} from "@material-ui/pickers";

const useStyles = makeStyles({
  grid: {
    width: "60%"
  },
  paper: {
    margin: 12,
    paddingBottom: 12
  },
  paperHeader: {
    color: "grey",
    padding: "12px"
  },
  paperHeaderAction: {
    padding: 12
  },
  paperActions: {
    justify: "flex-end",
    padding: 0,
    margin: 0
  },
  paperActionItem: {
    paddingRight: 0,
    paddingLeft: 40
  },
  item: {
    padding: "12px",
    paddingRight: "12px"
  },
  amount: {
    textAlign: "right"
  },
  formInput: {
    margin: 6
  },
  formContainer: {
    display: "flex"
  },
  innerContainer: {
    spacing: 12
  },
  innerLeftItem: {
    paddingLeft: 0,
    paddingRight: 12
  },
  innerRightItem: {
    paddingLeft: 12,
    paddingRight: 0
  },
  selectItem: {
    width: "100%"
  },
  textField: {
    width: "100%"
  },
  fab: {
    position: "absolute",
    bottom: 20,
    right: 20
  },
  readOnly: {
    color: "grey"
  }
});

const marks = [
  {
    value: 0,
    label: "very bad"
  },
  {
    value: 1,
    label: "bad"
  },
  {
    value: 2,
    label: "no so bad"
  },
  {
    value: 3,
    label: "rather good"
  },
  {
    value: 4,
    label: "good"
  },
  {
    value: 5,
    label: "very good"
  }
];

function valuetext(value) {
  return `${value}°C`;
}

function valueLabelFormat(value) {
  return marks.findIndex(mark => mark.value === value) + 1;
}

function createData(a, b, c, d, e, f, g, h, i, j, k) {
  return { a, b, c, d, e, f, g, h, i, j, k };
}

const rowsServices = [
  createData("A1  General Consultation", "1.00", "400.00"),
  createData("I113  BLOOD SUGAR-RANDOM OR FASTING", "1.00", "1250.00")
];

const rowsItems = [
  createData("0182  PARACETAMOL TABS 500 MG", "2.00", "10.00")
];

export default function MaterialUIPickers() {
  const classes = useStyles();

  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <form className={classes.formContainer} noValidate autoComplete="off">
        <Grid container>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={8} className={classes.paperHeader}>
                  <Typography variant="h6">Batch Processing</Typography>
                </Grid>
                <Grid container xs={4} justify="flex-end">
                  <Grid item className={classes.paperHeaderAction}>
                    <IconButton>
                      <SendIcon />
                    </IconButton>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-region">Region</InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-region"
                      type="text"
                      value="Ultha"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-district">
                      District
                    </InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-district"
                      type="text"
                      value="Rapta"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="visit-type">Year</InputLabel>
                    <Select
                      inputProps={{
                        name: "year",
                        id: "year"
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={1}>2019</MenuItem>
                      <MenuItem value={2}>2018</MenuItem>
                      <MenuItem value={3}>2017</MenuItem>
                    </Select>
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="visit-type">Month</InputLabel>
                    <Select
                      inputProps={{
                        name: "month",
                        id: "month"
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={1}>January</MenuItem>
                      <MenuItem value={2}>February</MenuItem>
                      <MenuItem value={3}>March</MenuItem>
                      <MenuItem value={4}>April</MenuItem>
                      <MenuItem value={5}>May</MenuItem>
                      <MenuItem value={6}>June</MenuItem>
                      <MenuItem value={7}>July</MenuItem>
                      <MenuItem value={8}>August</MenuItem>
                      <MenuItem value={9}>September</MenuItem>
                      <MenuItem value={10}>October</MenuItem>
                      <MenuItem value={11}>November</MenuItem>
                      <MenuItem value={12}>December</MenuItem>
                    </Select>
                  </FormControl>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={8} className={classes.paperHeader}>
                  <Typography variant="h6">Filter</Typography>
                </Grid>
                <Grid container xs={4} justify="flex-end">
                  <Grid item className={classes.paperHeaderAction}>
                    <IconButton>
                      <FilterListIcon />
                    </IconButton>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-region">Region</InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-region"
                      type="text"
                      value="Ultha"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-district">
                      District
                    </InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-district"
                      type="text"
                      value="Rapta"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-product">Product</InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-product"
                      type="text"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="adornment-category">
                      Category
                    </InputLabel>
                    <Input
                      fullWidth={true}
                      id="adornment-category"
                      type="text"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton size="small">
                            <MoreHoriz />
                          </IconButton>
                        </InputAdornment>
                      }
                    />
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="visit-type">Period Type</InputLabel>
                    <Select
                      inputProps={{
                        name: "periodType",
                        id: "periodType"
                      }}
                      value={1}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={1}>Monthly</MenuItem>
                      <MenuItem value={2}>Quarterly</MenuItem>
                      <MenuItem value={3}>Yearly</MenuItem>
                    </Select>
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="visit-type">Year</InputLabel>
                    <Select
                      inputProps={{
                        name: "year",
                        id: "year"
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={1}>2019</MenuItem>
                      <MenuItem value={2}>2018</MenuItem>
                      <MenuItem value={3}>2017</MenuItem>
                    </Select>
                  </FormControl>
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <FormControl fullWidth={true} className={classes.formInput}>
                    <InputLabel htmlFor="visit-type">Month</InputLabel>
                    <Select
                      inputProps={{
                        name: "month",
                        id: "month"
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={1}>January</MenuItem>
                      <MenuItem value={2}>February</MenuItem>
                      <MenuItem value={3}>March</MenuItem>
                      <MenuItem value={4}>April</MenuItem>
                      <MenuItem value={5}>May</MenuItem>
                      <MenuItem value={6}>June</MenuItem>
                      <MenuItem value={7}>July</MenuItem>
                      <MenuItem value={8}>August</MenuItem>
                      <MenuItem value={9}>September</MenuItem>
                      <MenuItem value={10}>October</MenuItem>
                      <MenuItem value={11}>November</MenuItem>
                      <MenuItem value={12}>December</MenuItem>
                    </Select>
                  </FormControl>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={8} className={classes.paperHeader}>
                  <Typography variant="h6">Display</Typography>
                </Grid>
                <Grid container xs={4} justify="flex-end">
                  <Grid item className={classes.paperHeaderAction} />
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={12} className={classes.item}>
                  ????
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={8} className={classes.paperHeader}>
                  <Typography variant="h6">Filter for Account</Typography>
                </Grid>
                <Grid container xs={4} justify="flex-end">
                  <Grid item className={classes.paperHeaderAction}>
                    <IconButton>
                      <ListAltIcon />
                    </IconButton>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={12}>
                  <Grid container>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="adornment-region">
                          Region
                        </InputLabel>
                        <Input
                          fullWidth={true}
                          id="adornment-region"
                          type="text"
                          value="Ultha"
                          endAdornment={
                            <InputAdornment position="end">
                              <IconButton size="small">
                                <MoreHoriz />
                              </IconButton>
                            </InputAdornment>
                          }
                        />
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="adornment-district">
                          District
                        </InputLabel>
                        <Input
                          fullWidth={true}
                          id="adornment-district"
                          type="text"
                          value="Rapta"
                          endAdornment={
                            <InputAdornment position="end">
                              <IconButton size="small">
                                <MoreHoriz />
                              </IconButton>
                            </InputAdornment>
                          }
                        />
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="adornment-hf">
                          Health Facility
                        </InputLabel>
                        <Input
                          fullWidth={true}
                          id="adornment-hf"
                          type="text"
                          endAdornment={
                            <InputAdornment position="end">
                              <IconButton size="small">
                                <MoreHoriz />
                              </IconButton>
                            </InputAdornment>
                          }
                        />
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="level">Level</InputLabel>
                        <Select
                          inputProps={{
                            name: "level",
                            id: "level"
                          }}
                        >
                          <MenuItem value="">
                            <em>None</em>
                          </MenuItem>
                          <MenuItem value={1}>Dispensary</MenuItem>
                          <MenuItem value={2}>Health Center</MenuItem>
                          <MenuItem value={3}>Hospital</MenuItem>
                        </Select>
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="batch">Batch</InputLabel>
                        <Select
                          inputProps={{
                            name: "batch",
                            id: "batch"
                          }}
                        >
                          <MenuItem value="">
                            <em>None</em>
                          </MenuItem>
                        </Select>
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="group">Group By</InputLabel>
                        <Select
                          value={1}
                          inputProps={{
                            name: "group",
                            id: "group"
                          }}
                        >
                          <MenuItem value="">
                            <em>None</em>
                          </MenuItem>
                          <MenuItem value={1}>Health Facility</MenuItem>
                          <MenuItem value={2}>Product</MenuItem>
                        </Select>
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControlLabel
                        control={<Checkbox />}
                        label="Show Claims"
                      />
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <FormControlLabel
                        control={<Checkbox />}
                        label="Show All"
                      />
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Date From"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </Grid>
                    <Grid item xs={3} className={classes.item}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Date To"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
        </Grid>
      </form>
    </MuiPickersUtilsProvider>
  );
}
